@@ -65,11 +65,30 @@ test_that("step_tfidf works with vocabulary argument", {
   )
 })
 
+test_that("bake method errors when needed non-standard role columns are missing", {
+  tokenized_test_data <- recipe(~text, data = test_data) %>%
+    step_tokenize(text) %>%
+    prep() %>%
+    bake(new_data = NULL)
+  
+  rec <- recipe(tokenized_test_data) %>%
+    update_role(text, new_role = "predictor") %>%
+    step_tfidf(text) %>%
+    update_role(text, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+  
+  trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
+  
+  expect_error(bake(trained, new_data = tokenized_test_data[, -1]),
+               class = "new_data_missing_column")
+})
+
 test_that("printing", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_tfidf(text)
   expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
 
 test_that("keep_original_cols works", {
